intelmq.bots.experts.wait package — intelmq 2.3.3.alpha1 documentation

# intelmq.bots.experts.wait package

## Submodules

## intelmq.bots.experts.wait.expert module

Created on Tue Jan 23 15:25:58 2018

@author: sebastian

`intelmq.bots.experts.wait.expert.` `BOT`

  alias of `intelmq.bots.experts.wait.expert.WaitExpertBot`

class `intelmq.bots.experts.wait.expert.` `WaitExpertBot`(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.Bot`

  `connect_redis`()
  `init`()
  `process`()

## Module contents